@import "../global.css";
@import "../glass.css";

/* ==================== Background ==================== */
.bg-white {
    background: #ffffff !important;
    padding: 40px 60px !important;
    margin: 0 !important;
    box-sizing: border-box !important;
    overflow: visible !important;
    min-height: auto !important;
    height: auto !important;
}

/* ==================== Voiceprint Container ==================== */
.voiceprint-container {
    position: fixed !important;
    top: 0 !important;
    left: 0 !important;
    right: 0 !important;
    bottom: 0 !important;
    display: flex !important;
    align-items: center !important;
    justify-content: center !important;
    padding: 60px 80px !important;
    padding-top: calc(108px + 30px) !important;
    box-sizing: border-box !important;
    overflow: auto !important;
    background: #ffffff !important;
}

/* ==================== Voiceprint Content ==================== */
.voiceprint-content {
    display: flex !important;
    gap: 60px !important;
    align-items: center !important;
    max-width: 100% !important;
    width: 100% !important;
    justify-content: center !important;
}

/* ==================== Left: Steps ==================== */
.voiceprint-steps {
    width: 280px !important;
    flex-shrink: 1 !important;
    min-width: 200px !important;
}

/* ==================== Center: Text ==================== */
.voiceprint-text {
    flex: 1 !important;
    display: flex !important;
    flex-direction: column !important;
    gap: 1rem !important;
    min-width: 50px !important;
    max-width: 500px !important;
}

/* ==================== Right: Button ==================== */
.voiceprint-button {
    width: 280px !important;
    flex-shrink: 1 !important;
    min-width: 220px !important;
    display: flex !important;
    flex-direction: column !important;
    align-items: center !important;
    gap: 2rem !important;
}

/* ==================== Timer ==================== */
.timer {
    font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', 'Helvetica Neue', Arial, sans-serif;
    font-size: 4rem;
    font-weight: 700;
    color: #1f2937;
    letter-spacing: 0.05em;
    text-align: center;
}

/* ==================== Recording Button ==================== */
.record-button {
    width: 180px !important;
    height: 180px !important;
    border-radius: 50% !important;
    transition: all 0.3s cubic-bezier(0.4, 0, 0.2, 1) !important;
    box-shadow: 0 8px 32px rgba(0, 0, 0, 0.15) !important;
}

.record-button:hover:not(:disabled) {
    transform: scale(1.05);
}

.record-button:active:not(:disabled) {
    transform: scale(0.98);
}

.record-button:disabled {
    opacity: 0.7 !important;
    cursor: not-allowed !important;
}

/* ==================== Recording Rings ==================== */
@keyframes pulse-ring {
    0% {
        transform: scale(1);
        opacity: 0.4;
    }
    100% {
        transform: scale(1.6);
        opacity: 0;
    }
}

.recording-ring {
    position: absolute;
    width: 180px;
    height: 180px;
    border-radius: 50%;
    pointer-events: none;
    background: radial-gradient(
        circle,
        transparent 45%,
        rgba(200, 200, 200, 0.3) 50%,
        rgba(160, 160, 160, 0.15) 55%,
        transparent 60%
    );
    filter: blur(8px);
    animation: pulse-ring 2.4s ease-out infinite;
}

/* ==================== Responsive Design ==================== */

@media (max-width: 1400px) {
    .voiceprint-container {
        padding: 40px 60px !important;
        padding-top: calc(108px + 20px) !important;
    }

    .voiceprint-content {
        gap: 40px !important;
    }

    .voiceprint-steps {
        width: 240px !important;
    }

    .voiceprint-button {
        width: 240px !important;
    }
}

@media (max-width: 1200px) {
    .voiceprint-container {
        padding: 30px 40px !important;
    }

    .voiceprint-content {
        gap: 30px !important;
    }

    .voiceprint-steps {
        width: 200px !important;
        min-width: 180px !important;
    }

    .voiceprint-button {
        width: 220px !important;
        min-width: 200px !important;
    }

    .timer {
        font-size: 3rem !important;
    }

    .record-button {
        width: 150px !important;
        height: 150px !important;
    }

    .recording-ring {
        width: 150px !important;
        height: 150px !important;
    }
}

@media (max-width: 768px) {
    .voiceprint-container {
        padding: 20px !important;
        padding-top: calc(108px + 10px) !important;
    }

    .voiceprint-content {
        gap: 20px !important;
    }

    .timer {
        font-size: 2.5rem !important;
    }

    .record-button {
        width: 120px !important;
        height: 120px !important;
    }

    .recording-ring {
        width: 120px !important;
        height: 120px !important;
    }
}
