# This file is auto-generated by PrototypeX stub generator.
# Do not edit manually - changes will be overwritten.
# Regenerate using: python -m scripts.genstubs gen

from __future__ import annotations

import datetime

from audex.entity import BaseEntity

class Segment(BaseEntity):
    id: str
    created_at: datetime.datetime
    updated_at: datetime.datetime | None
    session_id: str
    sequence: int
    audio_key: str
    started_at: datetime.datetime
    ended_at: datetime.datetime | None
    duration_ms: int | None
    def __init__(
        self,
        *,
        id: str = ...,
        created_at: datetime.datetime = ...,
        updated_at: datetime.datetime | None = None,
        session_id: str,
        sequence: int,
        audio_key: str,
        started_at: datetime.datetime = ...,
        ended_at: datetime.datetime | None = None,
        duration_ms: int | None = None,
    ) -> None: ...
    @property
    def is_recording(self) -> bool: ...
    def decr(self) -> None: ...
    def incr(self) -> None: ...
    def stop(self) -> None: ...
