/* ==================== Base Styles ==================== */

/* Smooth rendering */
* {
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}

html, body {
    margin: 0;
    padding: 0;
    overflow: hidden !important;
    height: 100vh;
    width: 100vw;
    background: #ffffff;
}

/* ==================== Layout Classes ==================== */

.items-center {
    align-items: center;
}

.justify-center {
    justify-content: center;
}

.gap-4 {
    gap: 1rem;
}

.mx-auto {
    margin-left: auto;
    margin-right: auto;
}

.mb-1 {
    margin-bottom: 0.25rem;
}

.mb-2 {
    margin-bottom: 0.5rem;
}

.mb-3 {
    margin-bottom: 0.75rem;
}

.mb-4 {
    margin-bottom: 1rem;
}

.mb-5 {
    margin-bottom: 1.25rem;
}

.mt-4 {
    margin-top: 1rem;
}

.my-3 {
    margin-top: 0.75rem;
    margin-bottom: 0.75rem;
}

.w-full {
    width: 100%;
}

.w-16 {
    width: 4rem;
}

.flex-1 {
    flex: 1;
}

.h-16 {
    height: 4rem;
}

/* ==================== Typography ==================== */

.text-xs {
    font-size: 0.75rem;
    line-height: 1rem;
}

.text-sm {
    font-size: 0.875rem;
    line-height: 1.25rem;
}

.text-h5 {
    font-size: 1.5rem;
    line-height: 2rem;
}

.text-center {
    text-align: center;
}

.text-grey-6 {
    color: #757575;
}

.text-grey-7 {
    color: #616161;
}

/* ==================== Login Card ==================== */

.login-card {
    border-radius: 28px !important;
    background: rgba(255, 255, 255, 0.98) !important;
    backdrop-filter: blur(20px) !important;
    -webkit-backdrop-filter: blur(20px) !important;
    box-shadow: 0 20px 60px rgba(0, 0, 0, 0.08), 0 8px 24px rgba(0, 0, 0, 0.05), 0 0 1px rgba(0, 0, 0, 0.1) !important;
    transition: all 0.3s cubic-bezier(0.4, 0, 0.2, 1) !important;
}

.login-card:hover {
    box-shadow: 0 24px 70px rgba(0, 0, 0, 0.1), 0 10px 28px rgba(0, 0, 0, 0.06), 0 0 1px rgba(0, 0, 0, 0.1) !important;
}

/* ==================== Background ==================== */

.bg-white {
    background: linear-gradient(135deg, #fafafa 0%, #ffffff 100%) !important;
}

/* ==================== Logo ==================== */

.login-logo {
    width: 64px !important;
    height: 64px !important;
    max-width: 100% !important;
    object-fit: contain !important;
    display: block !important;
}

/* ==================== Gradient Title ==================== */

.gradient-title {
    background: linear-gradient(135deg, #667eea 0%, #764ba2 50%, #f093fb 100%);
    background-size: 200% 200%;
    -webkit-background-clip: text;
    -webkit-text-fill-color: transparent;
    background-clip: text;
    font-weight: 700;
    animation: gradient-shift 6s ease infinite;
}

@keyframes gradient-shift {
    0%, 100% {
        background-position: 0 50%;
    }
    50% {
        background-position: 100% 50%;
    }
}

/* ==================== Clean Input ==================== */

.clean-input .q-field__control {
    background: transparent !important;
    border: none !important;
    border-radius: 0 !important;
    box-shadow: none !important;
    height: 48px !important;
}

.clean-input .q-field__native,
.clean-input input {
    color: #1f2937 !important;
    font-size: 15px !important;
    font-weight: 400 !important;
}

.clean-input .q-field__native::placeholder,
.clean-input input::placeholder {
    color: #9ca3af !important;
    opacity: 1 !important;
}

.clean-input .q-field__control:before {
    border: none !important;
    border-bottom: 1px solid rgba(0, 0, 0, 0.12) !important;
    transition: border-color 0.3s ease !important;
}

.clean-input .q-field__control:hover:before {
    border-bottom-color: rgba(0, 0, 0, 0.2) !important;
}

.clean-input .q-field__control:after {
    border: none !important;
    border-bottom: 2px solid #667eea !important;
    transform: scaleX(0);
    transition: transform 0.3s cubic-bezier(0.4, 0, 0.2, 1) !important;
}

.clean-input.q-field--focused .q-field__control:after {
    transform: scaleX(1);
}

.clean-input .q-field__append {
    height: 48px !important;
    display: flex !important;
    align-items: center !important;
    justify-content: center !important;
}

.clean-input .q-field__append .q-icon {
    color: #9ca3af !important;
    transition: color 0.2s ease !important;
}

.clean-input .q-field__append .q-icon:hover {
    color: #6b7280 !important;
}

/* ==================== Buttons ==================== */

/* Login button */
.login-button {
    border-radius: 24px !important;
    font-size: 16px !important;
    font-weight: 500 !important;
    letter-spacing: 0.02em !important;
    background: linear-gradient(135deg, #667eea 0%, #764ba2 100%) !important;
    box-shadow: 0 4px 16px rgba(102, 126, 234, 0.25), 0 2px 8px rgba(118, 75, 162, 0.15) !important;
    transition: all 0.3s cubic-bezier(0.4, 0, 0.2, 1) !important;
    text-transform: none !important;
}

.login-button:hover {
    transform: translateY(-2px);
    box-shadow: 0 8px 24px rgba(102, 126, 234, 0.35), 0 4px 12px rgba(118, 75, 162, 0.25) !important;
    background: linear-gradient(135deg, #7c8ef0 0%, #8a5db0 100%) !important;
}

.login-button:active {
    transform: translateY(0);
}

/* Register button */
.register-button {
    border-radius: 24px !important;
    border: 1px solid rgba(0, 0, 0, 0.08) !important;
    font-size: 16px !important;
    font-weight: 500 !important;
    letter-spacing: 0.02em !important;
    background: rgba(248, 249, 250, 0.6) !important;
    color: #6b7280 !important;
    box-shadow: 0 2px 8px rgba(0, 0, 0, 0.04) !important;
    transition: all 0.3s cubic-bezier(0.4, 0, 0.2, 1) !important;
    text-transform: none !important;
}

.register-button:hover {
    background: rgba(243, 244, 246, 0.8) !important;
    border-color: rgba(0, 0, 0, 0.12) !important;
    color: #4b5563 !important;
    box-shadow: 0 4px 12px rgba(0, 0, 0, 0.08) !important;
    transform: translateY(-2px);
}

.register-button:active {
    transform: translateY(0);
}

/* ==================== Separator ==================== */

.q-separator {
    background-color: rgba(0, 0, 0, 0.08) !important;
}

/* ==================== Responsive - Small Screens ==================== */

@media (max-height: 720px) {
    .login-card {
        padding: 24px 32px !important;
    }

    .login-logo {
        width: 56px !important;
        height: 56px !important;
    }

    .mb-4 {
        margin-bottom: 0.75rem !important;
    }
}

@media (max-height: 650px) {
    .login-card {
        padding: 20px 28px !important;
    }

    .login-logo {
        width: 48px !important;
        height: 48px !important;
    }

    .text-h5 {
        font-size: 1.25rem !important;
        line-height: 1.75rem !important;
    }

    .login-button,
    .register-button {
        height: 42px !important;
    }

    .mb-1 {
        margin-bottom: 0.125rem !important;
    }

    .mb-2 {
        margin-bottom: 0.25rem !important;
    }

    .mb-3 {
        margin-bottom: 0.5rem !important;
    }

    .mb-4 {
        margin-bottom: 0.5rem !important;
    }

    .my-3 {
        margin-top: 0.5rem !important;
        margin-bottom: 0.5rem !important;
    }
}

@media (max-height: 550px) {
    .login-card {
        padding: 16px 24px !important;
    }

    .login-logo {
        width: 40px !important;
        height: 40px !important;
    }

    .text-h5 {
        font-size: 1.125rem !important;
        line-height: 1.5rem !important;
    }

    .text-sm {
        font-size: 0.8125rem !important;
    }

    .login-button,
    .register-button {
        height: 38px !important;
        font-size: 15px !important;
    }
}

@media (max-height: 500px) and (orientation: landscape) {
    .login-card {
        padding: 12px 24px !important;
    }

    .login-logo {
        width: 32px !important;
        height: 32px !important;
    }

    .mb-1, .mb-2, .mb-3 {
        margin-bottom: 0.25rem !important;
    }

    .mb-4 {
        margin-bottom: 0.375rem !important;
    }

    .my-3 {
        margin-top: 0.375rem !important;
        margin-bottom: 0.375rem !important;
    }
}
