@import "global.css";
@import "glass.css";

/* ==================== Background ==================== */
.bg-white {
    background: #ffffff !important;
    padding: 40px 60px !important;
    margin: 0 !important;
    box-sizing: border-box !important;
    overflow: visible !important;
    min-height: auto !important;
    height: auto !important;
}

/* ==================== Tab Buttons ==================== */
.tab-button {
    padding: 12px 24px;
    border-radius: 12px;
    transition: all 0.2s cubic-bezier(0.4, 0, 0.2, 1);
    cursor: pointer;
    font-weight: 500;
    font-size: 15px;
    color: #6b7280;
    user-select: none;
}

.tab-button:hover {
    background: rgba(0, 0, 0, 0.04);
    color: #4b5563;
}

.tab-button-active {
    padding: 12px 24px;
    border-radius: 12px;
    cursor: pointer;
    font-weight: 600;
    font-size: 15px;
    background: linear-gradient(135deg, rgba(102, 126, 234, 0.12) 0%, rgba(118, 75, 162, 0.12) 100%);
    color: #667eea;
    box-shadow: 0 2px 8px rgba(102, 126, 234, 0.15);
    user-select: none;
}

/* ==================== Clean Input ==================== */
.clean-input .q-field__control {
    background: transparent !important;
    border: none !important;
    border-radius: 0 !important;
    box-shadow: none !important;
    height: 48px !important;
}

.clean-input .q-field__native,
.clean-input input {
    color: #1f2937 !important;
    font-size: 15px !important;
    font-weight: 400 !important;
}

.clean-input .q-field__native::placeholder,
.clean-input input::placeholder {
    color: #9ca3af !important;
    opacity: 1 !important;
}

.clean-input .q-field__control:before {
    border: none !important;
    border-bottom: 1px solid rgba(0, 0, 0, 0.12) !important;
    transition: border-color 0.3s ease !important;
}

.clean-input .q-field__control:hover:before {
    border-bottom-color: rgba(0, 0, 0, 0.2) !important;
}

.clean-input .q-field__control:after {
    border: none !important;
    border-bottom: 2px solid #667eea !important;
    transform: scaleX(0);
    transition: transform 0.3s cubic-bezier(0.4, 0, 0.2, 1) !important;
}

.clean-input.q-field--focused .q-field__control:after {
    transform: scaleX(1);
}

.clean-input .q-field__append {
    height: 48px !important;
    display: flex !important;
    align-items: center !important;
    justify-content: center !important;
}

.clean-input .q-field__append .q-icon {
    color: #9ca3af !important;
    transition: color 0.2s ease !important;
}

.clean-input .q-field__append .q-icon:hover {
    color: #6b7280 !important;
}

/* ==================== Action Button ==================== */
.action-button {
    border-radius: 24px !important;
    font-size: 16px !important;
    font-weight: 500 !important;
    letter-spacing: 0.02em !important;
    transition: all 0.2s cubic-bezier(0.4, 0, 0.2, 1) !important;
    min-width: 120px !important;
    text-transform: none !important;
}

.action-button:hover {
    transform: translateY(-2px);
}

.action-button:active {
    transform: translateY(0);
}

.action-button[color="primary"] {
    background: linear-gradient(135deg, #667eea 0%, #764ba2 100%) !important;
    box-shadow: 0 4px 16px rgba(102, 126, 234, 0.25), 0 2px 8px rgba(118, 75, 162, 0.15) !important;
}

.action-button[color="primary"]:hover {
    background: linear-gradient(135deg, #7c8ef0 0%, #8a5db0 100%) !important;
    box-shadow: 0 8px 24px rgba(102, 126, 234, 0.35), 0 4px 12px rgba(118, 75, 162, 0.25) !important;
}

.action-button[color="negative"]:hover {
    box-shadow: 0 4px 16px rgba(193, 0, 21, 0.25) !important;
}

/* ==================== Info Display ==================== */
.info-field {
    padding: 16px 0;
    border-bottom: 1px solid rgba(0, 0, 0, 0.06);
    transition: background 0.2s ease;
}

.info-field:hover {
    background: rgba(0, 0, 0, 0.01);
}

.info-field:last-child {
    border-bottom: none;
}

/* ==================== Separator ==================== */
.q-separator {
    background-color: rgba(0, 0, 0, 0.08) !important;
}

.my-8 .q-separator {
    background-color: rgba(0, 0, 0, 0.06) !important;
}

/* ==================== Dialog ==================== */
.q-dialog__backdrop {
    backdrop-filter: blur(4px) !important;
}

/* ==================== Responsive ==================== */
@media (max-width: 1400px) {
    .bg-white {
        padding: 40px 60px !important;
    }

    .px-6 {
        padding-left: 2.5rem !important;
        padding-right: 2.5rem !important;
    }
}

@media (max-width: 1024px) {
    .bg-white {
        padding: 30px 40px !important;
    }

    .px-6 {
        padding-left: 2rem !important;
        padding-right: 2rem !important;
    }
}
