# This file is auto-generated by PrototypeX stub generator.
# Do not edit manually - changes will be overwritten.
# Regenerate using: python -m scripts.genstubs gen

from __future__ import annotations

import datetime

from audex.entity import BaseEntity
from audex.valueobj.utterance import Speaker

class Utterance(BaseEntity):
    id: str
    created_at: datetime.datetime
    updated_at: datetime.datetime | None
    session_id: str
    segment_id: str
    sequence: int
    speaker: Speaker
    text: str
    confidence: float | None
    start_time_ms: int
    end_time_ms: int
    timestamp: datetime.datetime
    def __init__(
        self,
        *,
        id: str = ...,
        created_at: datetime.datetime = ...,
        updated_at: datetime.datetime | None = None,
        session_id: str,
        segment_id: str,
        sequence: int,
        speaker: Speaker,
        text: str,
        confidence: float | None = None,
        start_time_ms: int,
        end_time_ms: int,
        timestamp: datetime.datetime = ...,
    ) -> None: ...
    @property
    def duration_ms(self) -> int: ...
    @property
    def is_doctor(self) -> bool: ...
    @property
    def is_patient(self) -> bool: ...
    def decr(self) -> None: ...
    def incr(self) -> None: ...
