# This file is auto-generated by PrototypeX stub generator.
# Do not edit manually - changes will be overwritten.
# Regenerate using: python -m scripts.genstubs gen

from __future__ import annotations

import datetime

from audex.entity import BaseEntity

class VP(BaseEntity):
    id: str
    created_at: datetime.datetime
    updated_at: datetime.datetime | None
    doctor_id: str
    vpr_uid: str
    vpr_group_id: str
    audio_key: str
    text_content: str
    sample_rate: int
    is_active: bool
    def __init__(
        self,
        *,
        id: str = ...,
        created_at: datetime.datetime = ...,
        updated_at: datetime.datetime | None = None,
        doctor_id: str,
        vpr_uid: str,
        vpr_group_id: str,
        audio_key: str,
        text_content: str,
        sample_rate: int,
        is_active: bool = True,
    ) -> None: ...
