/* ==================== Base Styles ==================== */
/* Smooth rendering */
* {
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}

html, body {
    margin: 0;
    padding: 0;
    overflow: hidden;
    overflow-y: auto;
    height: 100vh;
    width: 100vw;
    background: #ffffff;
}

::-webkit-scrollbar {
    width: 0;
    height: 0;
}

* {
    scrollbar-width: none; /* Firefox */
}

* {
    -ms-overflow-style: none;
}

/* ==================== Layout Classes ==================== */
/* Flex */
.items-center {
    align-items: center;
}

.items-start {
    align-items: flex-start;
}

.items-baseline {
    align-items: baseline;
}

.items-end {
    align-items: flex-end;
}

.justify-center {
    justify-content: center;
}

.justify-start {
    justify-content: flex-start;
}

.justify-between {
    justify-content: space-between;
}

.justify-end {
    justify-content: flex-end;
}

.self-end {
    align-self: flex-end;
}

.flex-1 {
    flex: 1;
}

/* Spacing */
.gap-0 {
    gap: 0;
}

.gap-1 {
    gap: 0.25rem;
}

.gap-2 {
    gap: 0.5rem;
}

.gap-3 {
    gap: 0.75rem;
}

.gap-4 {
    gap: 1rem;
}

.gap-8 {
    gap: 2rem;
}

/* Padding */
.px-1 {
    padding-left: 0.25rem;
    padding-right: 0.25rem;
}

.px-2 {
    padding-left: 0.5rem;
    padding-right: 0.5rem;
}

.px-3 {
    padding-left: 0.75rem;
    padding-right: 0.75rem;
}

.px-4 {
    padding-left: 1rem;
    padding-right: 1rem;
}

.px-5 {
    padding-left: 1.25rem;
    padding-right: 1.25rem;
}

.px-6 {
    padding-left: 3rem !important;
    padding-right: 3rem !important;
}

.px-7 {
    padding-left: 1.75rem;
    padding-right: 1.75rem;
}

.px-8 {
    padding-left: 2rem;
    padding-right: 2rem;
}

.py-1 {
    padding-top: 0.25rem;
    padding-bottom: 0.25rem;
}

.py-2 {
    padding-top: 0.5rem;
    padding-bottom: 0.5rem;
}

.py-3 {
    padding-top: 0.75rem;
    padding-bottom: 0.75rem;
}

.py-4 {
    padding-top: 1rem;
    padding-bottom: 1rem;
}

.py-5 {
    padding-top: 1.25rem;
    padding-bottom: 1.25rem;
}

.py-6 {
    padding-top: 1.5rem;
    padding-bottom: 1.5rem;
}

.py-7 {
    padding-top: 1.75rem;
    padding-bottom: 1.75rem;
}

.py-8 {
    padding-top: 2rem;
    padding-bottom: 2rem;
}

.p-1 {
    padding: 0.25rem;
}

.p-2 {
    padding: 0.5rem;
}

.p-3 {
    padding: 0.75rem;
}

.p-4 {
    padding: 1rem;
}

.p-5 {
    padding: 1.25rem;
}

.p-7 {
    padding: 1.75rem;
}

.p-8 {
    padding: 2rem;
}

/* Margin */
.mb-0 {
    margin-bottom: 0;
}

.mb-1 {
    margin-bottom: 0.25rem;
}

.mb-2 {
    margin-bottom: 0.5rem;
}

.mb-3 {
    margin-bottom: 0.75rem;
}

.mb-4 {
    margin-bottom: 1rem;
}

.mb-5 {
    margin-bottom: 1.25rem;
}

.mb-6 {
    margin-bottom: 1.5rem;
}

.mb-7 {
    margin-bottom: 1.75rem;
}

.mb-8 {
    margin-bottom: 2rem;
}

.mb-auto {
    margin-bottom: auto;
}

.mt-0 {
    margin-top: 0;
}

.mt-1 {
    margin-top: 0.25rem;
}

.mt-2 {
    margin-top: 0.5rem;
}

.mt-3 {
    margin-top: 0.75rem;
}

.mt-4 {
    margin-top: 1rem;
}

.mt-5 {
    margin-top: 1.25rem;
}

.mt-6 {
    margin-top: 1.5rem;
}

.mt-7 {
    margin-top: 1.75rem;
}

.mt-8 {
    margin-top: 2rem;
}

.my-8 {
    margin-top: 2rem;
    margin-bottom: 2rem;
}

.q-ml-sm {
    margin-left: 0.5rem;
}

/* Width */
.w-1 {
    width: 0.25rem;
}

.w-2 {
    width: 0.5rem;
}

.w-3 {
    width: 0.75rem;
}

.w-4 {
    width: 1rem;
}

.w-5 {
    width: 1.25rem;
}

.w-6 {
    width: 1.5rem;
}

.w-7 {
    width: 1.75rem;
}

.w-8 {
    width: 2rem;
}

.w-9 {
    width: 2.25rem;
}

.w-10 {
    width: 2.5rem;
}

.w-full {
    width: 100%;
}

/* Height */
.h-1 {
    height: 0.25rem;
}

.h-2 {
    height: 0.5rem;
}

.h-3 {
    height: 0.75rem;
}

.h-4 {
    height: 1rem;
}

.h-5 {
    height: 1.25rem;
}

.h-6 {
    height: 1.5rem;
}

.h-7 {
    height: 1.75rem;
}

.h-8 {
    height: 2rem;
}

.h-9 {
    height: 2.25rem;
}

.h-10 {
    height: 2.5rem;
}

.h-full {
    height: 100%;
}

/* ==================== Typography ==================== */
.text-xs {
    font-size: 0.75rem;
    line-height: 1rem;
}

.text-sm {
    font-size: 0.875rem;
    line-height: 1.25rem;
}

.text-body1 {
    font-size: 1rem;
    line-height: 1.5rem;
}

.text-body2 {
    font-size: 0.875rem;
    line-height: 1.25rem;
}

.text-subtitle2 {
    font-size: 0.875rem;
    line-height: 1.375rem;
    font-weight: 500;
}

.text-h1 {
    font-size: 3rem;
    line-height: 3.5rem;
}

.text-h2 {
    font-size: 2.5rem;
    line-height: 3rem;
}

.text-h3 {
    font-size: 2rem;
    line-height: 2.5rem;
}

.text-h4 {
    font-size: 1.875rem;
    line-height: 2.25rem;
}

.text-h5 {
    font-size: 1.5rem;
    line-height: 2rem;
}

.text-h6 {
    font-size: 1.25rem;
    line-height: 1.75rem;
}

.text-lg {
    font-size: 1.125rem;
    line-height: 1.75rem;
}

.text-center {
    text-align: center;
}

/* Font Weight */
.font-medium {
    font-weight: 500;
}

.font-medium {
    font-weight: 500;
}

.font-semibold {
    font-weight: 600;
}

.font-bold {
    font-weight: 700;
}

.font-mono {
    font-family: monospace;
}

/* Text Color */
.text-black {
    color: #000000;
}

.text-white {
    color: #ffffff;
}

.text-grey-1 {
    color: #f5f5f5;
}

.text-grey-2 {
    color: #eeeeee;
}

.text-grey-3 {
    color: #e0e0e0;
}

.text-grey-4 {
    color: #bdbdbd;
}

.text-grey-5 {
    color: #9e9e9e;
}

.text-grey-6 {
    color: #757575;
}

.text-grey-7 {
    color: #616161;
}

.text-grey-8 {
    color: #424242;
}

.text-grey-9 {
    color: #212121;
}

.text-primary {
    color: #1976d2;
}

.text-secondary {
    color: #9c27b0;
}

.text-positive {
    color: #4caf50;
}

.text-negative {
    color: #c10015;
}

.text-warning {
    color: #ff9800;
}

.text-info {
    color: #0288d1;
}

.cursor-pointer {
    cursor: pointer;
}
